==> netwosixwebadmin-0.0.1-src.tar.gz: netwosixwebadmin-0.0.1/src/libagent/agent.c <==
/**
 * WebAdmin
 * Copyright (C) 2006 Netwosix Team
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with this program; if not, write to the Free Software 
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * Linking WebAdmin statically or dynamically with other modules is making
 * a combined work based on WebAdmin. Thus, the terms and conditions of the 
 * GNU General Public License cover the whole combination.
 *
 * In addition, as a special exception, the copyright holders of
 * WebAdmin give you permission to combine WebAdmin with free software
 * programs or libraries that are released under the GNU LGPL and with
 * code included in the standard release of OpenSSL under the OpenSSL
 * License and SSLeay License (or modified versions of such code, with
 * unchanged licenses). You may copy and distribute such a system
 * following the terms of the GNU GPL for WebAdmin and the licenses of
 * the other code concerned, provided that you include the source code of
 * that other code when and as the GNU GPL requires distribution of
 * source code.
 *
 * Note that people who make modified versions of WebAdmin are not obligated
 * to grant this special exception for their modified versions; 
 * it is their choice whether to do so. The GNU General Public License 
 * gives permission to release a modified version without this exception; 
 * this exception also makes it possible to release a modified 
 * version which carries forward this exception.
 */

#include "agent.h"



/**
 */
int agent_main(int argc, char ** argv, agent_response_create_func func)
{
	AlConnectionManager     * connection_manager = NULL;
	AlConnection            * connection = NULL;
	AgentRequestPacket      * request_packet = NULL;
	AgentResponsePacket     * response_packet = NULL;
	pid_t                     pid = 0;
	char                    * connection_type;
	AlXmlNode               * node;
	AlString                * s;




	if ((connection_manager = al_stdio_connection_manager_new()) == NULL)
		al_exit (1, "Could not open stdin connection.\n");


	while (1)
	{
		connection = al_connection_manager_wait(connection_manager);
		if (connection == NULL) break;

		if (al_connection_manager_need_fork(connection_manager)) pid = fork();
		if (pid == 0 || !al_connection_manager_need_fork(connection_manager))
		{
			while (1)
			{
				s = al_connection_read(connection);
				if (s == NULL) break;

				request_packet = agent_request_packet_from_xml_string(s);
				al_string_delete(s);

				response_packet = agent_response_packet_from_request_packet(request_packet, func);
				if (response_packet)
				{
					s = agent_response_packet_to_xml_string(response_packet);
					al_connection_send(connection, s);
					al_string_delete(s);
				}
			}
			al_connection_delete(connection);
			if (al_connection_manager_need_fork(connection_manager)) break;
		}

	}


	if (connection_manager) al_connection_manager_delete(connection_manager);


	return 0;
}

==> netwosixwebadmin-0.0.2-src.tar.gz: netwosixwebadmin-0.0.2/src/libagent/agent.c <==
/**
 * WebAdmin
 * Copyright (C) 2006 Netwosix Team
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with this program; if not, write to the Free Software 
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * Linking WebAdmin statically or dynamically with other modules is making
 * a combined work based on WebAdmin. Thus, the terms and conditions of the 
 * GNU General Public License cover the whole combination.
 *
 * In addition, as a special exception, the copyright holders of
 * WebAdmin give you permission to combine WebAdmin with free software
 * programs or libraries that are released under the GNU LGPL and with
 * code included in the standard release of OpenSSL under the OpenSSL
 * License and SSLeay License (or modified versions of such code, with
 * unchanged licenses). You may copy and distribute such a system
 * following the terms of the GNU GPL for WebAdmin and the licenses of
 * the other code concerned, provided that you include the source code of
 * that other code when and as the GNU GPL requires distribution of
 * source code.
 *
 * Note that people who make modified versions of WebAdmin are not obligated
 * to grant this special exception for their modified versions; 
 * it is their choice whether to do so. The GNU General Public License 
 * gives permission to release a modified version without this exception; 
 * this exception also makes it possible to release a modified 
 * version which carries forward this exception.
 */

#include "agent.h"


/** */
static int agent_argc = 0;

/** */
static char ** agent_argv = NULL;


/**
 */
int agent_main(int argc, char ** argv, agent_response_create_func func)
{
	AlConnectionManager     * connection_manager = NULL;
	AlConnection            * connection = NULL;
	AgentRequestPacket      * request_packet = NULL;
	AgentResponsePacket     * response_packet = NULL;
	AlString                * s;


	agent_argc = argc;
	agent_argv = argv;
	
	if ((connection_manager = al_stdio_connection_manager_new()) == NULL)
		al_exit (1, "Could not open stdin connection.\n");

	while (1)
	{
		connection = al_connection_manager_wait(connection_manager);
		if (connection == NULL) break;

		while (1)
		{
			s = al_connection_read(connection);
			if (s == NULL) break;

			request_packet = agent_request_packet_from_xml_string(s);
			al_string_delete(s);

			response_packet = agent_response_packet_from_request_packet(request_packet, func);
			if (response_packet)
			{
				s = agent_response_packet_to_xml_string(response_packet);
				al_connection_send(connection, s);
				al_string_delete(s);
			}
		}
		
		al_connection_delete(connection);
	}

	if (connection_manager) al_connection_manager_delete(connection_manager);

	al_exit (0, NULL);
	
	return 0;
}


/**
 */
char ** agent_get_args(int * argc)
{
	*argc = agent_argc;
	
	return agent_argv;
}
